summaryrefslogtreecommitdiff
path: root/render/box.h
diff options
context:
space:
mode:
authorMichael Drake <tlsa@netsurf-browser.org>2011-03-05 22:18:06 +0000
committerMichael Drake <tlsa@netsurf-browser.org>2011-03-05 22:18:06 +0000
commit9be22ab5908a50fef1f53c366fd68204a15f939c (patch)
tree6cc4c694d37f282553bb0d7c44b18f04e581716e /render/box.h
parentf892e59d76da3a67db642b91f0f0779f976ea8ba (diff)
downloadnetsurf-9be22ab5908a50fef1f53c366fd68204a15f939c.tar.gz
netsurf-9be22ab5908a50fef1f53c366fd68204a15f939c.tar.bz2
Make sure the last clone box for a wrapped text is properly measuered.
svn path=/trunk/netsurf/; revision=11920
Diffstat (limited to 'render/box.h')
-rw-r--r--render/box.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/render/box.h b/render/box.h
index 522aeafd1..7d7cd84a6 100644
--- a/render/box.h
+++ b/render/box.h
@@ -122,7 +122,8 @@ typedef enum {
STYLE_OWNED = 1 << 1, /* style is owned by this box */
PRINTED = 1 << 2, /* box has already been printed */
PRE_STRIP = 1 << 3, /* PRE tag needing leading newline stripped */
- CLONE = 1 << 4 /* continuation of previous box from wrapping */
+ CLONE = 1 << 4, /* continuation of previous box from wrapping */
+ MEASURED = 1 << 5 /* text box width has been measured */
} box_flags;
/* Sides of a box */